#!/bin/bash
# openstack-base script

set -x

CONFIG_FILE="openstack.cfg"
 
cat > $CONFIG_FILE <<DELIM_
nova-cloud-controller:
    network-manager: "Neutron"
    console-access-protocol: "novnc"
    openstack-origin: "cloud:trusty-liberty"
    quantum-security-groups: "yes"
nova-compute:
    enable-live-migration: "True"
    enable-resize: "True"
    openstack-origin: "cloud:trusty-liberty"
    migration-auth-type: "ssh"
    #virt-type: "qemu"
    disable-neutron-security-groups: False
neutron-api:
    openstack-origin: "cloud:trusty-liberty"
    neutron-security-groups: "True"
keystone:
    openstack-origin: "cloud:trusty-liberty"
    admin-password: "plumgrid"
cinder:
    openstack-origin: "cloud:trusty-liberty"
openstack-dashboard:
    openstack-origin: "cloud:trusty-liberty"
glance:
    openstack-origin: "cloud:trusty-liberty"
rabbitmq-server:
    source: cloud:trusty-liberty
neutron-gateway:
    ext-port: eth1
    openstack-origin: cloud:trusty-liberty  
DELIM_

# Deploying two nodes
juju deploy ubuntu
juju add-unit ubuntu

# Deploying all openstack charms on plumgrid-director node
echo "Deploying mysql charm ..."
juju deploy --to lxc:1 mysql
echo "Deploying rabbitmq charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 rabbitmq-server
echo "Deploying keystone charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 keystone
echo "Deploying nova-cloud-controller charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 nova-cloud-controller
echo "Deploying glance charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 glance
echo "Deploying openstack-dashboard charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 openstack-dashboard
echo "Deploying cinder charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 cinder
echo "Deploying neutron-api charm ..."
juju deploy --config=$CONFIG_FILE --to lxc:1 neutron-api

# Deploying nova-compute on bootstrap node
echo "Deploying nova-compute charm ..."
juju deploy --config=$CONFIG_FILE --to 0 nova-compute
echo "Deploying plumgrid-edge charm ..."
juju deploy neutron-openvswitch

# Deploying neutron-gateway
echo "Deploying neutron-gateway charm ..."
juju deploy --config=$CONFIG_FILE --to 2 neutron-gateway


# Adding relations
juju add-relation mysql keystone
juju add-relation nova-cloud-controller mysql
juju add-relation nova-compute mysql
juju add-relation glance mysql
juju add-relation mysql cinder
juju add-relation neutron-api mysql
juju add-relation nova-cloud-controller keystone
juju add-relation glance keystone
juju add-relation cinder keystone
juju add-relation neutron-api keystone
juju add-relation openstack-dashboard keystone
juju add-relation nova-compute neutron-openvswitch
juju add-relation rabbitmq-server neutron-openvswitch
juju add-relation neutron-api neutron-openvswitch
juju add-relation neutron-api neutron-gateway
juju add-relation nova-cloud-controller neutron-gateway
juju add-relation rabbitmq-server neutron-gateway
juju add-relation nova-cloud-controller rabbitmq-server
juju add-relation nova-cloud-controller glance
juju add-relation nova-compute nova-cloud-controller
juju add-relation nova-compute rabbitmq-server
juju add-relation nova-compute glance
juju add-relation glance cinder
juju add-relation cinder rabbitmq-server
juju add-relation cinder nova-cloud-controller
juju add-relation neutron-api rabbitmq-server
juju add-relation neutron-api nova-cloud-controller

# Exposing services
juju expose openstack-dashboard
juju expose nova-cloud-controller
